- Make `xotl.tools.infinity.Infinity`:class: comparable with unknown types by
  returning NotImplemented instead of raising the error directly.  See MR `!28
  <https://gitlab.merchise.org/merchise/xoutil/merge_requests/28>`__ for an
  example.
